@@ -6,6 +6,7 @@ import unicodedata
 import uuid
 from io import BytesIO
 from itertools import groupby
+from operator import attrgetter
 
 import genshi
 import genshi.template
@@ -217,7 +218,7 @@ class Group(metaclass=PoolMeta):
         Payment = pool.get('account.payment')
         Mandate = pool.get('account.payment.sepa.mandate')
         if self.kind == 'receivable':
-            payments = list(self.payments)
+            payments = sorted(self.payments, key=attrgetter('date', 'id'))
             mandates = Payment.get_sepa_mandates(payments)
             Mandate.lock(list(filter(None, mandates)))
             sequence_types = {}
@@ -660,11 +661,12 @@ class Mandate(Workflow, ModelSQL, ModelView):
         vlist = [v.copy() for v in vlist]
         default_company = cls.default_company()
         for values in vlist:
-            if (config.sepa_mandate_sequence
-                    and not values.get('identification')):
-                values['identification'] = config.get_multivalue(
+            if not values.get('identification'):
+                sequence = config.get_multivalue(
                     'sepa_mandate_sequence',
-                    company=values.get('company', default_company)).get()
+                    company=values.get('company', default_company))
+                if sequence:
+                    values['identification'] = sequence.get()
             # Prevent raising false unique constraint
             if values.get('identification') == '':
                 values['identification'] = None
